#include "testApp.h"
#include "particle.h"

//--------------------------------------------------------------
void testApp::setup(){
	
	ofSetVerticalSync(true);
	ofSetFrameRate(60);
	
	mySound.loadSound("boom.wav");
	mySound.setLoop(true);
	
	ofColor color;
	color.r = ofRandom(20, 250);
	color.g = ofRandom(20, 250);
	color.b = ofRandom(20, 250);
	color.a = 255;

	float radius = 20;
	float angle = ofGetElapsedTimef()*5;
	
	int x = ofRandom(100 , 900);
	int y = ofRandom(100, 600);
	
	for(int i = 0; i < 1000; ++i) {
	particle myParticle;
	mySound.play();
		
	float vx = x + radius *cos(angle);
	float vy = y + radius * -sin(angle);	
		
	myParticle.setInitialCondition(x, y, vx, vy);
	myParticle.damping = ofRandom(0, 0.05);
	myParticle.setColor(color);
	_particles.push_back(myParticle);
	}

	_start_time = ofGetElapsedTimef();
}

//--------------------------------------------------------------
void testApp::update() {
	mySound.setSpeed(1.05f);
	vector<particle>::iterator it;

	
	float curr_time = ofGetElapsedTimef();
	
	if(curr_time - _start_time >= DIEOUT ) {
		int x = ofRandom(20, ofGetWidth()-20);
		int y = ofRandom(20, ofGetHeight()-20);
		
		ofColor color;
		color.r = ofRandom(0, 255);
		color.g = ofRandom(0, 255);
		color.b = ofRandom(0, 255);
		color.a = 255;
		
		for(it = _particles.begin(); it != _particles.end(); ++it) {
			float vx = ofRandom(-4,4);
			float vy = ofRandom(-4,4);
			it->setInitialCondition(x, y, vx, vy);	
			it->setColor(color);
		}
		_start_time = curr_time;
	}
	
	for(it = _particles.begin(); it != _particles.end(); ++it) {
		it->resetForce();
		it->addForce(0,0.02);  // gravity
		it->addDampingForce();
		it->update();
		it->setAlpha(ofMap(curr_time, _start_time, _start_time + DIEOUT , 255, 0, true));
	}
}

//--------------------------------------------------------------
void testApp::draw() {

	ofBackground(0, 0, 0);

	vector<particle>::iterator it;
	for(it = _particles.begin(); it != _particles.end(); ++it){
		it->draw();
	}
	
}

//--------------------------------------------------------------
void testApp::keyPressed(int key){

}

//--------------------------------------------------------------
void testApp::keyReleased(int key){

}

//--------------------------------------------------------------
void testApp::mouseMoved(int x, int y ){

}

//--------------------------------------------------------------
void testApp::mouseDragged(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mousePressed(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::mouseReleased(int x, int y, int button){

}

//--------------------------------------------------------------
void testApp::windowResized(int w, int h){

}

